# Liveness Detection SDK

This is a Python SDK for performing liveness detection using a pre-trained deep learning model. The SDK uses OpenCV for face detection and TensorFlow for liveness prediction.

## Installation

You can install this SDK using pip:

